@@ -8,8 +8,8 @@ class Queue(object):
         self.name = name
         self.backend = backend
 
-    def put(self, payload):
-        self.backend.put(self.name, payload)
+    def put(self, payload, priority=0):
+        self.backend.put(self.name, payload, priority=priority)
 
     def get(self):
         payload = self.backend.get(self.name)
@@ -66,7 +66,10 @@ class QueueSet(object):
 
         while True:
             # Get the next queue in the cycle, and try to get an item off it.
-            queue = self.cycle.next()
+            try:
+                queue = self.cycle.next()
+            except StopIteration:
+                raise Empty("No queues registered")
             try:
                 item = queue.get()
             except Empty:
